@@ -32,8 +32,7 @@
  *          Raph Levien <raph@gimp.org>
  */
 
-#ifndef EEL_CANVAS_H
-#define EEL_CANVAS_H
+#pragma once
 
 #include <gtk/gtk.h>
 #include <gtk/gtk-a11y.h>
@@ -495,6 +494,4 @@ struct _EelCanvasItemAccessibleClass
 	GtkAccessibleClass parent_class;
 };
 
-G_END_DECLS
-
-#endif
+G_END_DECLS
\ No newline at end of file
