@@ -20,7 +20,7 @@
 #include <glib/gi18n.h>
 
 #include "nautilus-file-name-widget-controller.h"
-
+#include "nautilus-file-utilities.h"
 
 #define FILE_NAME_DUPLICATED_LABEL_TIMEOUT 500
 
@@ -72,6 +72,31 @@ nautilus_file_name_widget_controller_set_containing_directory (NautilusFileNameW
     g_object_set (self, "containing-directory", directory, NULL);
 }
 
+gboolean
+nautilus_file_name_widget_controller_is_name_too_long (NautilusFileNameWidgetController  *self,
+                                                       gchar                             *name)
+{
+    NautilusFileNameWidgetControllerPrivate *priv;
+    size_t name_length;
+    g_autoptr (GFile) location = NULL;
+    glong max_name_length;
+
+    priv = nautilus_file_name_widget_controller_get_instance_private (self);
+    name_length = strlen (name);
+    location = nautilus_directory_get_location (priv->containing_directory);
+    max_name_length = nautilus_get_max_child_name_length_for_location (location);
+
+    if (max_name_length == -1)
+    {
+        /* We don't know, so let's give it a chance */
+        return FALSE;
+    }
+    else
+    {
+        return name_length > max_name_length + 1;
+    }
+}
+
 static gboolean
 nautilus_file_name_widget_controller_name_is_valid (NautilusFileNameWidgetController  *self,
                                                     gchar                             *name,
@@ -105,30 +130,41 @@ real_name_is_valid (NautilusFileNameWidgetController  *self,
                     gchar                             *name,
                     gchar                            **error_message)
 {
+    gboolean is_valid;
+
+    is_valid = TRUE;
     if (strlen (name) == 0)
     {
-        return FALSE;
+        is_valid = FALSE;
     }
-
-    if (strstr (name, "/") != NULL)
+    else if (strstr (name, "/") != NULL)
     {
+        is_valid = FALSE;
         *error_message = _("File names cannot contain “/”.");
     }
     else if (strcmp (name, ".") == 0)
     {
+        is_valid = FALSE;
         *error_message = _("A file cannot be called “.”.");
     }
     else if (strcmp (name, "..") == 0)
     {
+        is_valid = FALSE;
         *error_message = _("A file cannot be called “..”.");
     }
-    else if (g_str_has_prefix (name, "."))
+    else if (nautilus_file_name_widget_controller_is_name_too_long (self, name))
     {
-        *error_message = _("Files with “.” at the beginning of their name are hidden.");
-        return TRUE;
+        is_valid = FALSE;
+        *error_message = _("File name is too long.");
     }
 
-    return *error_message == NULL;
+    if (is_valid && g_str_has_prefix (name, "."))
+    {
+        /* We must warn about the side effect */
+        *error_message = _("Files with “.” at the beginning of their name are hidden.");
+    }
+
+    return is_valid;
 }
 
 static gboolean
