@@ -15,10 +15,9 @@
  * License along with this library; if not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <string.h>
 #include "nautilus-icon-info.h"
-#include <gtk/gtk.h>
-#include <gio/gio.h>
+
+#include "nautilus-enums.h"
 
 struct _NautilusIconInfo
 {
@@ -337,10 +336,10 @@ nautilus_icon_info_lookup (GIcon *icon,
                            int    scale)
 {
     NautilusIconInfo *icon_info;
-    GdkPixbuf *pixbuf;
 
     if (G_IS_LOADABLE_ICON (icon))
     {
+        GdkPixbuf *pixbuf;
         LoadableIconKey lookup_key;
         LoadableIconKey *key;
         GInputStream *stream;
