@@ -20,8 +20,7 @@
  * 
  */
 
-#ifndef NAUTILUS_MODULE_H
-#define NAUTILUS_MODULE_H
+#pragma once
 
 #include <glib-object.h>
 
@@ -37,5 +36,3 @@ void   nautilus_module_extension_list_free     (GList *list);
 void   nautilus_module_add_type                (GType  type);
 
 G_END_DECLS
-
-#endif
