@@ -1,11 +1,4 @@
-#include <glib.h>
-#include "src/nautilus-directory.h"
-#include "src/nautilus-file-utilities.h"
-#include "src/nautilus-search-directory.h"
-#include "src/nautilus-directory.h"
-#include "src/nautilus-file-operations.c"
-#include <unistd.h>
-#include "eel/eel-string.h"
+#include "test-utilities.h"
 
 static void
 test_trash_one_file (void)
@@ -14,31 +7,24 @@ test_trash_one_file (void)
     g_autoptr (GFile) first_dir = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
-    GFileOutputStream *out = NULL;
-    g_autoptr (GError) error = NULL;
+
+    create_one_file ("trash_or_delete");
 
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
 
     file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
     g_assert_true (file != NULL);
-    out = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-    {
-        g_object_unref (out);
-    }
     files = g_list_prepend (files, g_object_ref (file));
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_trash_or_delete_sync (files);
 
     g_assert_false (g_file_query_exists (file, NULL));
-    g_assert_true (g_file_delete (first_dir, NULL, NULL));
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -47,40 +33,36 @@ test_trash_more_files_func (gint files_to_trash)
     g_autoptr (GFile) root = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
-    GFileOutputStream *out = NULL;
+
+    create_multiple_files ("trash_or_delete", files_to_trash);
  
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
  
     for (int i = 0; i < files_to_trash; i++)
     {
-        g_autofree gchar *file_name = NULL;
-        g_autoptr (GError) error = NULL;
+        gchar *file_name;
  
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_true (file != NULL);
-        out = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
-        if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-        {
-            g_object_unref (out);
-        }
         files = g_list_prepend (files, g_object_ref (file));
     }
  
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_trash_or_delete_sync (files);
  
     for (int i = 0; i < files_to_trash; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_false (g_file_query_exists (file, NULL));
     }
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -96,31 +78,24 @@ test_delete_one_file (void)
     g_autoptr (GFile) first_dir = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
-    GFileOutputStream *out = NULL;
-    g_autoptr (GError) error = NULL;
+
+    create_one_file ("trash_or_delete");
 
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
 
     file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
     g_assert_true (file != NULL);
-    out = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-    {
-        g_object_unref (out);
-    }
     files = g_list_prepend (files, g_object_ref (file));
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
 
     g_assert_false (g_file_query_exists (file, NULL));
-    g_assert_true (g_file_delete (first_dir, NULL, NULL));
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -129,40 +104,36 @@ test_delete_more_files_func (gint files_to_delete)
     g_autoptr (GFile) root = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
-    GFileOutputStream *out = NULL;
+
+    create_multiple_files ("trash_or_delete", files_to_delete);
  
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
  
     for (int i = 0; i < files_to_delete; i++)
     {
-        g_autofree gchar *file_name = NULL;
-        g_autoptr (GError) error = NULL;
+        gchar *file_name;
  
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_true (file != NULL);
-        out = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
-        if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-        {
-            g_object_unref (out);
-        }
         files = g_list_prepend (files, g_object_ref (file));
     }
  
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
  
     for (int i = 0; i < files_to_delete; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_false (g_file_query_exists (file, NULL));
     }
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -176,22 +147,27 @@ test_trash_one_empty_directory (void)
 {
     g_autoptr (GFile) root = NULL;
     g_autoptr (GFile) first_dir = NULL;
+    g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
 
+    create_one_empty_directory ("trash_or_delete");
+
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
 
-    files = g_list_prepend (files, g_object_ref (first_dir));
+    file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
+    g_assert_true (file != NULL);
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    files = g_list_prepend (files, g_object_ref (file));
 
-    g_assert_false (g_file_query_exists (first_dir, NULL));
+    nautilus_file_operations_trash_or_delete_sync (files);
+
+    g_assert_false (g_file_query_exists (file, NULL));
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -201,35 +177,37 @@ test_trash_more_empty_directories_func (gint directories_to_trash)
     g_autoptr (GFile) file = NULL;
     g_autoptr (GFile) dir = NULL;
     g_autolist (GFile) files = NULL;
+
+    create_multiple_directories ("trash_or_delete", directories_to_trash);
  
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
  
     for (int i = 0; i < directories_to_trash; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_true (file != NULL);
-        g_file_make_directory (file, NULL, NULL);
         files = g_list_prepend (files, g_object_ref (file));
     }
  
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_trash_or_delete_sync (files);
 
     for (int i = 0; i < directories_to_trash; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_true (file != NULL);
         g_assert_false (g_file_query_exists (file, NULL));
     }
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -243,22 +221,26 @@ test_delete_one_empty_directory (void)
 {
     g_autoptr (GFile) root = NULL;
     g_autoptr (GFile) first_dir = NULL;
+    g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
 
+    create_one_empty_directory ("trash_or_delete");
+
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
+    file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
+    g_assert_true (file != NULL);
 
-    files = g_list_prepend (files, g_object_ref (first_dir));
+    files = g_list_prepend (files, g_object_ref (file));
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
 
-    g_assert_false (g_file_query_exists (first_dir, NULL));
+    g_assert_false (g_file_query_exists (file, NULL));
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -268,35 +250,38 @@ test_delete_more_empty_directories_func (gint directories_to_delete)
     g_autoptr (GFile) file = NULL;
     g_autoptr (GFile) dir = NULL;
     g_autolist (GFile) files = NULL;
+
+    create_multiple_directories ("trash_or_delete", directories_to_delete);
  
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
  
     for (int i = 0; i < directories_to_delete; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_true (file != NULL);
-        g_file_make_directory (file, NULL, NULL);
         files = g_list_prepend (files, g_object_ref (file));
     }
  
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
+
 
     for (int i = 0; i < directories_to_delete; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_true (file != NULL);
         g_assert_false (g_file_query_exists (file, NULL));
     }
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -305,43 +290,42 @@ test_delete_more_empty_directories (void)
     test_delete_more_empty_directories_func (100);
 }
 
+/* The hierarchy looks like this:
+ * /tmp/first_dir/first_dir_child
+ * We're trashing first_dir.
+ */
 static void
-test_trash_one_full_directory (void)
+test_trash_full_directory (void)
 {
     g_autoptr (GFile) root = NULL;
     g_autoptr (GFile) first_dir = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
-    GFileOutputStream *out = NULL;
-    g_autoptr (GError) error = NULL;
+
+    create_one_file ("trash_or_delete");
 
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
 
     file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
     g_assert_true (file != NULL);
-    out = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-    {
-        g_object_unref (out);
-    }
 
     files = g_list_prepend (files, g_object_ref (first_dir));
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_trash_or_delete_sync (files);
 
     g_assert_false (g_file_query_exists (first_dir, NULL));
     g_assert_false (g_file_query_exists (file, NULL));
-}
 
+    empty_directory_by_prefix (root, "trash_or_delete");
+}
+ 
 /* The hierarchy looks like this:
- * /tmp/first_dir/first_dir_child
+ * /tmp/first_dir/first_child
+ * /tmp/first_dir/second_child
  * We're trashing first_dir.
  */
 static void
@@ -351,59 +335,22 @@ test_trash_first_hierarchy (void)
     g_autoptr (GFile) first_dir = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
+
+    create_first_hierarchy ("trash_or_delete");
  
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     files = g_list_prepend (files, g_object_ref (first_dir));
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
- 
-    file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
-    g_assert_true (file != NULL);
-    g_file_make_directory (file, NULL, NULL);
- 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
-
-    g_assert_false (g_file_query_exists (file, NULL));
-
-    g_assert_false (g_file_query_exists (first_dir, NULL)); 
-}
- 
-/* The hierarchy looks like this:
- * /tmp/first_dir/first_child
- * /tmp/first_dir/second_child
- * We're trashing first_dir.
- */
-static void
-test_trash_second_hierarchy (void)
-{
-    g_autoptr (GFile) root = NULL;
-    g_autoptr (GFile) first_dir = NULL;
-    g_autoptr (GFile) file = NULL;
-    g_autolist (GFile) files = NULL;
- 
-    root = g_file_new_for_path (g_get_tmp_dir ());
-    first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
-    files = g_list_prepend (files, g_object_ref (first_dir));
-    g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
  
     file = g_file_get_child (first_dir, "trash_or_delete_first_child");
     g_assert_true (file != NULL);
-    g_file_make_directory (file, NULL, NULL);
     file = g_file_get_child (first_dir, "trash_or_delete_second_child");
     g_assert_true (file != NULL);
-    g_file_make_directory (file, NULL, NULL);
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_trash_or_delete_sync (files);
 
     file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
     g_assert_false (g_file_query_exists (file, NULL));
@@ -412,6 +359,8 @@ test_trash_second_hierarchy (void)
     g_assert_false (g_file_query_exists (file, NULL));
 
     g_assert_false (g_file_query_exists (first_dir, NULL));
+
+    empty_directory_by_prefix (root, "trash_or_delete");
  }
 
 /* We're creating 50 directories each containing one file
@@ -424,82 +373,80 @@ test_trash_third_hierarchy (void)
     g_autoptr (GFile) directory = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
- 
+
+    create_multiple_full_directories ("trash_or_delete", 50);
+
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
 
     for (int i = 0; i < 50; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_directory_%i", i);
 
         directory = g_file_get_child (root, file_name);
-        g_file_make_directory (directory, NULL, NULL);
+        g_free (file_name);
         files = g_list_prepend (files, g_object_ref (directory));
-
-        file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
-        file = g_file_get_child (directory, file_name);
-        g_file_make_directory (file, NULL, NULL);
     }
  
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   TRUE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_trash_or_delete_sync (files);
 
     for (int i = 0; i < 50; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_directory_%i", i);
 
         directory = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_false (g_file_query_exists (directory, NULL));
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (directory, file_name);
+        g_free (file_name);
         g_assert_false (g_file_query_exists (file, NULL));
     }
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
+/* The hierarchy looks like this:
+ * /tmp/first_dir/first_dir_child
+ * We're deleting first_dir.
+ */
 static void
-test_delete_one_full_directory (void)
+test_delete_full_directory (void)
 {
     g_autoptr (GFile) root = NULL;
     g_autoptr (GFile) first_dir = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
-    GFileOutputStream *out = NULL;
-    g_autoptr (GError) error = NULL;
+
+    create_one_file ("trash_or_delete");
 
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
 
     file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
     g_assert_true (file != NULL);
-    out = g_file_create (file, G_FILE_CREATE_NONE, NULL, &error);
-    if (!g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
-    {
-        g_object_unref (out);
-    }
 
     files = g_list_prepend (files, g_object_ref (first_dir));
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
 
     g_assert_false (g_file_query_exists (first_dir, NULL));
     g_assert_false (g_file_query_exists (file, NULL));
-}
 
+    empty_directory_by_prefix (root, "trash_or_delete");
+}
+ 
 /* The hierarchy looks like this:
- * /tmp/first_dir/first_dir_child
+ * /tmp/first_dir/first_child
+ * /tmp/first_dir/second_child
  * We're deleting first_dir.
  */
 static void
@@ -509,59 +456,22 @@ test_delete_first_hierarchy (void)
     g_autoptr (GFile) first_dir = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
+
+    create_first_hierarchy ("trash_or_delete");
  
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
+
     first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
     files = g_list_prepend (files, g_object_ref (first_dir));
     g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
- 
-    file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
-    g_assert_true (file != NULL);
-    g_file_make_directory (file, NULL, NULL);
- 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
-
-    g_assert_false (g_file_query_exists (file, NULL));
-
-    g_assert_false (g_file_query_exists (first_dir, NULL)); 
-}
- 
-/* The hierarchy looks like this:
- * /tmp/first_dir/first_child
- * /tmp/first_dir/second_child
- * We're deleting first_dir.
- */
-static void
-test_delete_second_hierarchy (void)
-{
-    g_autoptr (GFile) root = NULL;
-    g_autoptr (GFile) first_dir = NULL;
-    g_autoptr (GFile) file = NULL;
-    g_autolist (GFile) files = NULL;
- 
-    root = g_file_new_for_path (g_get_tmp_dir ());
-    first_dir = g_file_get_child (root, "trash_or_delete_first_dir");
-    files = g_list_prepend (files, g_object_ref (first_dir));
-    g_assert_true (first_dir != NULL);
-    g_file_make_directory (first_dir, NULL, NULL);
  
     file = g_file_get_child (first_dir, "trash_or_delete_first_child");
     g_assert_true (file != NULL);
-    g_file_make_directory (file, NULL, NULL);
     file = g_file_get_child (first_dir, "trash_or_delete_second_child");
     g_assert_true (file != NULL);
-    g_file_make_directory (file, NULL, NULL);
 
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
 
     file = g_file_get_child (first_dir, "trash_or_delete_first_dir_child");
     g_assert_false (g_file_query_exists (file, NULL));
@@ -570,6 +480,8 @@ test_delete_second_hierarchy (void)
     g_assert_false (g_file_query_exists (file, NULL));
 
     g_assert_false (g_file_query_exists (first_dir, NULL));
+
+    empty_directory_by_prefix (root, "trash_or_delete");
  }
 
 /* We're creating 50 directories each containing one file
@@ -582,43 +494,42 @@ test_delete_third_hierarchy (void)
     g_autoptr (GFile) directory = NULL;
     g_autoptr (GFile) file = NULL;
     g_autolist (GFile) files = NULL;
- 
+
+    create_multiple_full_directories ("trash_or_delete", 50);
+
     root = g_file_new_for_path (g_get_tmp_dir ());
+    g_assert_true (root != NULL);
 
     for (int i = 0; i < 50; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_directory_%i", i);
 
         directory = g_file_get_child (root, file_name);
-        g_file_make_directory (directory, NULL, NULL);
+        g_free (file_name);
         files = g_list_prepend (files, g_object_ref (directory));
-
-        file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
-        file = g_file_get_child (directory, file_name);
-        g_file_make_directory (file, NULL, NULL);
     }
  
-    trash_or_delete_internal_sync (files,
-                                   NULL,
-                                   FALSE,
-                                   NULL,
-                                   NULL);
+    nautilus_file_operations_delete_sync (files);
 
     for (int i = 0; i < 50; i++)
     {
-        g_autofree gchar *file_name = NULL;
+        gchar *file_name;
 
         file_name = g_strdup_printf ("trash_or_delete_directory_%i", i);
 
         directory = g_file_get_child (root, file_name);
+        g_free (file_name);
         g_assert_false (g_file_query_exists (directory, NULL));
 
         file_name = g_strdup_printf ("trash_or_delete_file_%i", i);
         file = g_file_get_child (directory, file_name);
+        g_free (file_name);
         g_assert_false (g_file_query_exists (file, NULL));
     }
+
+    empty_directory_by_prefix (root, "trash_or_delete");
 }
 
 static void
@@ -641,19 +552,15 @@ setup_test_suite (void)
     g_test_add_func ("/test-delete-more-directories/1.0",
                      test_delete_more_empty_directories);
     g_test_add_func ("/test-trash-one-full-directory/1.0",
-                     test_trash_one_full_directory);
+                     test_trash_full_directory);
     g_test_add_func ("/test-trash-one-full-directory/1.1",
                      test_trash_first_hierarchy);
-    g_test_add_func ("/test-trash-one-full-directory/1.2",
-                     test_trash_second_hierarchy);
-    g_test_add_func ("/test-trash-more-full-directories/1.6",
+    g_test_add_func ("/test-trash-more-full-directories/1.2",
                      test_trash_third_hierarchy);
     g_test_add_func ("/test-delete-one-full-directory/1.0",
-                     test_delete_one_full_directory);
+                     test_delete_full_directory);
     g_test_add_func ("/test-delete-one-full-directory/1.1",
                      test_delete_first_hierarchy);
-    g_test_add_func ("/test-delete-one-full-directory/1.2",
-                     test_delete_second_hierarchy);
     g_test_add_func ("/test-delete-more-full-directories/1.6",
                      test_delete_third_hierarchy);
 
